@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,18 +18,15 @@
 
 #include "configurepluginslistwidget.h"
 
-#include <KConfigGroup>
 #include <KSharedConfig>
 #include <KLocalizedString>
 
-#include <QHBoxLayout>
-#include <QLabel>
 #include <QPushButton>
 #include <QToolButton>
 #include <QTreeWidget>
 #include <QHeaderView>
-#include <QDebug>
 #include <QAction>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
@@ -88,7 +86,6 @@ void ConfigurePluginsListWidget::doResetToDefaultsOther()
 
 void ConfigurePluginsListWidget::defaults()
 {
-
 }
 
 void ConfigurePluginsListWidget::initialize()
@@ -110,14 +107,13 @@ void ConfigurePluginsListWidget::savePlugins(const QString &groupName, const QSt
         }
     }
     PimCommon::PluginUtil::savePluginSettings(groupName,
-            prefixSettingKey,
-            enabledPlugins, disabledPlugins);
+                                              prefixSettingKey,
+                                              enabledPlugins, disabledPlugins);
 }
 
-void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName,
-        const QString &groupName, const QString &prefixKey, QList<PluginItem *> &itemsList, const QString &configureGroupName)
+void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUtilData> &lst, const QString &topLevelItemName, const QString &groupName, const QString &prefixKey,
+                                              QList<PluginItem *> &itemsList, const QString &configureGroupName)
 {
-
     itemsList.clear();
     if (!lst.isEmpty()) {
         QTreeWidgetItem *topLevel = new QTreeWidgetItem(mListWidget, QStringList() << topLevelItemName);
@@ -136,7 +132,9 @@ void ConfigurePluginsListWidget::fillTopItems(const QVector<PimCommon::PluginUti
             if (data.mHasConfigureDialog) {
                 QToolButton *but = new QToolButton(mListWidget);
                 QAction *act = new QAction(but);
-                const QStringList actData { configureGroupName, data.mIdentifier };
+                const QStringList actData {
+                    configureGroupName, data.mIdentifier
+                };
                 act->setData(actData);
                 but->setDefaultAction(act);
                 but->setIcon(QIcon::fromTheme(QStringLiteral("configure")));
