@@ -2,8 +2,9 @@
   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,6 +19,7 @@
 #include "logactivitiesdialog.h"
 #include "logactivitieswidget.h"
 #include "logactivitiesmanager.h"
+#include "logactivitiespurposemenuwidget.h"
 #include <PimCommon/PimUtil>
 #include <KLocalizedString>
 #include <KConfigGroup>
@@ -56,6 +58,20 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mSaveButton = buttonBox->button(QDialogButtonBox::Save);
     mSaveButton->setObjectName(QStringLiteral("savebutton"));
     mSaveButton->setEnabled(false);
+
+    LogactivitiesPurposeMenuWidget *purposeMenu = new LogactivitiesPurposeMenuWidget(this, this);
+    if (purposeMenu->menu()) {
+        mShareButton = new QPushButton(i18n("Share..."), this);
+        mShareButton->setMenu(purposeMenu->menu());
+        mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+        purposeMenu->setEditorWidget(mLogWidget->editor());
+        buttonBox->addButton(mShareButton, QDialogButtonBox::ActionRole);
+        mShareButton->setEnabled(false);
+    } else {
+        delete purposeMenu;
+    }
+
+
     connect(mSaveButton, &QPushButton::clicked, this, &LogActivitiesDialog::slotSave);
 
     mainLayout->addWidget(buttonBox);
@@ -64,16 +80,24 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
 
     connect(PimCommon::LogActivitiesManager::self(), &LogActivitiesManager::logEntryAdded, this, &LogActivitiesDialog::slotLogEntryAdded);
     connect(PimCommon::LogActivitiesManager::self(), &LogActivitiesManager::logEntryCleared, this, &LogActivitiesDialog::slotLogEntryCleared);
-    connect(mLogWidget, &LogActivitiesWidget::textChanged, mSaveButton, &QPushButton::setEnabled);
+    connect(mLogWidget, &LogActivitiesWidget::textChanged, this, &LogActivitiesDialog::slotActivityTextChanged);
     mEnableLogActivities->setChecked(PimCommon::LogActivitiesManager::self()->enableLogActivities());
 }
 
 LogActivitiesDialog::~LogActivitiesDialog()
 {
-    disconnect(mLogWidget, &LogActivitiesWidget::textChanged, mSaveButton, &QPushButton::setEnabled);
+    disconnect(mLogWidget, &LogActivitiesWidget::textChanged, this, &LogActivitiesDialog::slotActivityTextChanged);
     writeConfig();
 }
 
+void LogActivitiesDialog::slotActivityTextChanged(bool changed)
+{
+    mSaveButton->setEnabled(changed);
+    if (mShareButton) {
+        mShareButton->setEnabled(changed);
+    }
+}
+
 void LogActivitiesDialog::slotSave()
 {
     const QString filter = i18n("All Files (*)");
