@@ -2,8 +2,9 @@
   Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -34,14 +35,14 @@ class PIMCOMMON_EXPORT TemplateListWidget : public QListWidget
     Q_OBJECT
 public:
     explicit TemplateListWidget(const QString &configName, QWidget *parent = nullptr);
-    ~TemplateListWidget();
+    ~TemplateListWidget() override;
 
     //Need to load template in specific class to allow to use correct defaultTemplates function
     void loadTemplates();
 
-    virtual QVector<PimCommon::defaultTemplate> defaultTemplates();
-    virtual bool addNewTemplate(QString &templateName, QString &templateScript);
-    virtual bool modifyTemplate(QString &templateName, QString &templateScript, bool defaultTemplate);
+    Q_REQUIRED_RESULT virtual QVector<PimCommon::defaultTemplate> defaultTemplates();
+    Q_REQUIRED_RESULT virtual bool addNewTemplate(QString &templateName, QString &templateScript);
+    Q_REQUIRED_RESULT virtual bool modifyTemplate(QString &templateName, QString &templateScript, bool defaultTemplate);
 
     void setKNewStuffConfigFile(const QString &configName);
 
