@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -24,23 +25,18 @@ class PimCommon::KActionMenuChangeCasePrivate
 {
 public:
     KActionMenuChangeCasePrivate()
-        : mUpperCase(nullptr),
-          mSentenceCase(nullptr),
-          mLowerCase(nullptr),
-          mReverseCase(nullptr)
     {
-
     }
 
-    QAction *mUpperCase;
-    QAction *mSentenceCase;
-    QAction *mLowerCase;
-    QAction *mReverseCase;
+    QAction *mUpperCase = nullptr;
+    QAction *mSentenceCase = nullptr;
+    QAction *mLowerCase = nullptr;
+    QAction *mReverseCase = nullptr;
 };
 
 KActionMenuChangeCase::KActionMenuChangeCase(QObject *parent)
-    : KActionMenu(parent),
-      d(new PimCommon::KActionMenuChangeCasePrivate)
+    : KActionMenu(parent)
+    , d(new PimCommon::KActionMenuChangeCasePrivate)
 {
     setText(i18n("Change Case"));
     d->mUpperCase = new QAction(i18n("Uppercase"), this);
